@@ -14,9 +14,9 @@ print(f"Settings file {__file__}")
 # SITE_ID = SiteID(default=105)  # Mpigi
 # SITE_ID = SiteID(default=106)  # Namayumba
 # SITE_ID = SiteID(default=107)  # Namulonge
-# SITE_ID = SiteID(default=108)  # Ndejje
+SITE_ID = SiteID(default=108)  # Ndejje
 # SITE_ID = SiteID(default=109)  # Sekiwunga
-SITE_ID = SiteID(default=110)  # Wakiso
+# SITE_ID = SiteID(default=110)  # Wakiso
 
 # TZ
 # SITE_ID = SiteID(default=201)  # Amana
